aboutsummaryrefslogtreecommitdiffstats
path: root/core.go
diff options
context:
space:
mode:
Diffstat (limited to 'core.go')
-rw-r--r--core.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/core.go b/core.go
index 0ae6da1..74a72b9 100644
--- a/core.go
+++ b/core.go
@@ -34,9 +34,9 @@ func (li *LineItem) Id() string {
}
// The main anchor of a BOM as a cohesive whole, with a name and permissions.
// Multiple BOMs are associated with a single BomStub; the currently active one
// is the 'head'.
-type BomStub struct {
+type BomMeta struct {
Name string `json:"name"`
Owner string `json:"owner_name"`
Description string `json:"description"`
@@ -87,7 +87,7 @@ func (b *Bom) Validate() error {
return nil
}
-func (bs *BomStub) Validate() error {
+func (bs *BomMeta) Validate() error {
if !isShortName(bs.Name) {
return Error("name not a ShortName: \"" + bs.Name + "\"")
}
@@ -34,9 +34,9 @@ func (li *LineItem) Id() string {
}
// The main anchor of a BOM as a cohesive whole, with a name and permissions.
-// Multiple BOMs are associated with a single BomStub; the currently active one
+// Multiple BOMs are associated with a single BomMeta; the currently active one
// is the 'head'.